"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const clipboardy = require("clipboardy");
const elementtree = require("elementtree");
// @ts-ignore: No types
const envinfo = require("envinfo");
const execa = require("execa");
const fse = require("fs-extra");
const _ = require("lodash");
const readPkgUp = require("read-pkg-up");
const collectionAndroidManifestInfo = async () => {
    const content = await fse.readFile('platforms/android/app/src/main/AndroidManifest.xml', 'utf8');
    const etree = elementtree.parse(content);
    const items = etree.findall('./application/meta-data/[@android:name="com.google.android.gms.ads.APPLICATION_ID"]');
    return {
        count: items.length,
        toString() {
            switch (items.length) {
                case 0:
                    return 'missing <meta-data android:name="com.google.android.gms.ads.APPLICATION_ID" ... />';
                case 1:
                    return items[0].get('android:value') === 'test'
                        ? 'using test APPLICATION_ID'
                        : 'looks ok';
                default:
                    return 'multiple <meta-data android:name="com.google.android.gms.ads.APPLICATION_ID" ... />';
            }
        },
    };
};
class InfoCommand extends command_1.Command {
    async run() {
        const { flags: parsedFlags } = this.parse(InfoCommand);
        const { pkg } = await readPkgUp();
        let infoText = '';
        try {
            infoText = await envinfo.run({
                Binaries: ['Node', 'Yarn', 'npm', 'Watchman'],
                IDEs: ['Xcode', 'Android Studio'],
                Languages: ['Java'],
                SDKs: ['iOS SDK', 'Android SDK'],
                System: ['OS', 'CPU', 'Memory', 'Shell'],
                npmGlobalPackages: ['cordova', 'ionic'],
                npmPackages: [
                    'cordova-android',
                    'cordova-browser',
                    'cordova-ios',
                    ..._.keys(_.get(pkg, 'cordova.plugins')),
                    'cordova-admob-plus',
                    'cordova',
                    'ionic*',
                    '@ionic*',
                ],
            }, {
                console: false,
                title: 'AdMob Plus Environment Info',
            });
        }
        catch (err) {
            this.log(err);
        }
        if (infoText.indexOf('cordova') === -1) {
            const { stdout: cordovaVersion } = await execa('cordova', ['--version'], {
                reject: false,
            });
            infoText += `\ncordova: ${cordovaVersion}\n`;
            const { stdout: ionicVersion } = await execa('ionic', ['--version'], {
                reject: false,
            });
            infoText += `ionic: ${ionicVersion}\n`;
            const deps = Object.assign({}, pkg.devDependencies, pkg.dependencies);
            const cordovaPlugins = _.reduce(_.get(pkg, 'cordova.plugins'), (acc, v, k) => (Object.assign({}, acc, { [k]: deps[k] })), {});
            infoText += `cordova plugins: ${JSON.stringify(cordovaPlugins, null, 2)}\n`;
        }
        try {
            const androidInfo = await collectionAndroidManifestInfo();
            infoText += `\nAndroidManifest.xml: ${androidInfo}\n`;
            // tslint:disable-next-line:no-empty
        }
        catch (err) { }
        this.log(infoText);
        if (parsedFlags.clipboard) {
            clipboardy.writeSync(infoText);
        }
    }
}
InfoCommand.description = 'Get relevant version info about OS, toolchain and libraries';
InfoCommand.examples = [`$ admob-plus info`];
InfoCommand.flags = {
    clipboard: command_1.flags.boolean({
        description: 'copy the environment report output to the clipboard',
    }),
    help: command_1.flags.help({ char: 'h' }),
};
InfoCommand.args = [];
exports.default = InfoCommand;
